<?php
/**
 * wordplus functions and definitions.
 *
 * @subpackage wordplus
 * @since wordplus 0.1.0
 */

// Content Width
if ( ! isset( $content_width ) )
	$content_width = 700;
	
/*-- Setup wordplus Features --*/
//textDomain, automatic-feed-link, editor-style, html5, post-formats, nav-menu, post-thumbnails

function wordplus_setup(){
	load_theme_textdomain( 'wordplus', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );
	add_theme_support( 'post-formats', array(
		'aside', 'audio', 'chat', 'gallery', 'image', 'link', 'quote', 'status', 'video'
	) );
	add_theme_support( 'title-tag' );
	add_editor_style('css/editor-style.css');
	register_nav_menu( 'header_menu', __( 'Header Menu', 'wordplus' ) );
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 600,270 , true );
	add_filter( 'use_default_gallery_style', '__return_false' );
	}

add_action( 'after_setup_theme', 'wordplus_setup',11 ); 

/**
 * Registers five widget areas.
 *	1.Sidebar widget area
 *	2.Sticky Widget Area
 *  3.Full Width Footer Widget Area
 *  4.Half Width Footer Widget Area
 *  5.OneThird Width Footer Widget Area
 */
function wordplus_widgets_init() {

	register_sidebar( array(
		'name'          => __( 'Sidebar Widget Area', 'wordplus' ),
		'id'            => 'sidebar',
		'description'   =>__('Widgets Area on Right Hand','wordplus'),
		'before_widget' => '<aside id="%1$s" class="side-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title" >',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Sticky Widget Area', 'wordplus' ),
		'id'            => 'sticky-sidebar',
		'description'   =>__('An Sticky Widget Area on top and bottom ','wordplus'),
		'before_widget' => '<aside id="%1$s" class="side-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title" >',
		'after_title'   => '</h3>',
	) );
			
		
	register_sidebar( array(
		'name'          => __( 'OneThird Width Footer Widget Area', 'wordplus' ),
		'id'            => 'footer-onethirdwidth',
		'description'   => __( 'Shows Widgets in OneThird Footer Area', 'wordplus' ),
		'before_widget' => '<li><aside id="%1$s" class="footer-widget onethird-width %2$s">',
		'after_widget'  => '</aside></li>',
		'before_title'  => '<h3 class="footer-widget-title" >',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'wordplus_widgets_init' );



/* Enqueue scripts and styles */

function wordplus_functions_js(){
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ){
			wp_enqueue_script( 'comment-reply' );
	}
wp_register_script('functions',get_template_directory_uri().'/js/functions.js',array('jquery','jquery-ui-tooltip'));
wp_enqueue_script('functions');
wp_register_script('scrolltofixed',get_template_directory_uri().'/js/scrolltofixed.js',array('jquery'));
wp_enqueue_script('scrolltofixed');
wp_register_script('sticky-widget',get_template_directory_uri().'/js/sticky-widget.js',array('jquery','scrolltofixed'));
wp_enqueue_script('sticky-widget');
wp_register_script('fit-video',get_template_directory_uri().'/js/FitVids/jquery.fitvids.js',array('jquery','scrolltofixed'));
wp_enqueue_script('fit-video');
wp_enqueue_script('scrollReveal',get_template_directory_uri().'/js/scrollReveal/scrollReveal.js',array());
wp_enqueue_style('fontello',get_template_directory_uri().'/fonts/font-icon/css/fontello.css');
wp_enqueue_style( 'wordplus-style', get_stylesheet_uri(), array(), '2013' );
wp_enqueue_style( 'wordplus-ie', get_template_directory_uri() . '/css/ie.css', array( 'wordplus-style' ), '2013' );
wp_style_add_data( 'wordplus-ie', 'conditional', 'lt IE 9' );
if ( is_rtl() ) {
  wp_deregister_style( 'wordplus-style', get_template_directory_uri() . '/style.css');
  wp_enqueue_style( 'wordplus-rtl', get_template_directory_uri() . '/wordplus-rtl.css');
 }
}
add_action('wp_enqueue_scripts','wordplus_functions_js');
 //-------------- body class -------------------------------------------
 
add_action('wp_head', create_function("",'ob_start();') );
add_action('get_sidebar', 'wordplus_sidebar_class');
add_action('wp_footer', 'wordplus_sidebar_class_replace');
 
function wordplus_sidebar_class($name=''){
	if ((is_active_sidebar('sidebar') || is_active_sidebar('sticky-sidebar'))&& !is_page()) :
		static $class="withsidebar";
		if(!empty($name))$class.=" sidebar-{$name}";
		wordplus_sidebar_class_replace($class);
	elseif ((is_active_sidebar('sidebar') || is_active_sidebar('sticky-sidebar'))&& (is_page_template( 'page-templates/front-page.php') || is_page_template( 'search.php'))):
		static $class="withsidebar";
		if(!empty($name))$class.=" sidebar-{$name}";
		wordplus_sidebar_class_replace($class);
	endif;
}

function wordplus_sidebar_class_replace($c=''){
  static $class='';
  if(!empty($c)) $class=$c;
  else {
    echo str_replace('<body class="','<body class="'.$class.' ',ob_get_clean());
    ob_start();
  }
}
//-------------- excerpt more -------------------------------------------
function wordplus_excerpt_more( $more ) {
	       global $post;
		   $more_text=__('... Read More','wordplus');
	return '<a class="more-link" href="'. get_permalink($post->ID) . '">'.$more_text.'</a>';
}
add_filter('excerpt_more', 'wordplus_excerpt_more');

//-------------- wp title -----------------------------------------
function wordplus_wp_title( $title, $sep ){
	global $paged, $page;

	if ( is_feed() )
		return $title;

	$title .= get_bloginfo( 'name' );

	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'wordplus' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'wordplus_wp_title', 10, 2 );


//-------------- paginatioin -------------------------------------------
function wordplus_pagination(){
	global $wp_query;

			$big = 999999999; 
			echo paginate_links( array(
				'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
				'format' => '?paged=%#%',
				'current' => max( 1, get_query_var('paged') ),
				'total' => $wp_query->max_num_pages,
				'prev_text'    => __('<i class="icon-left-open"></i>','wordplus'),
				'next_text'    => __('<i class="icon-right-open"></i>','wordplus')
			) );
}
//-----------------------------------------
function wordplus_tag_cloud_sizes($args) {
$args['smallest'] =8;
$args['largest'] = 14;
return $args; }
add_filter('widget_tag_cloud_args','wordplus_tag_cloud_sizes');

//-----------------------------------------
function wordplus_get_link_url() {
	$content = get_the_content();
	$has_url = get_url_in_content( $content );

	return ( $has_url ) ? $has_url : apply_filters( 'the_permalink', get_permalink() );
}
//------ post thumbnail -------------------
function wordplus_post_thumbnail(){
global $post,$wp_query;
if ( has_post_thumbnail() && ! post_password_required()){
	if((!is_single() && esc_attr(get_theme_mod('wordplus_featured_image_show'))=='yes') || (is_single() && esc_attr(get_theme_mod('wordplus_f_img_show_single')) == 'yes')){ ?>
				<div class="post-thumbnail">
					<?php the_post_thumbnail('post-thumbnail'); ?>
				</div>
	<?php }
	}
}
//------ navigation widget -----------------
add_action( 'widgets_init', 'wordplus_widget' );

function wordplus_widget() {
	register_widget( 'wordplus_Widget' );
}

class wordplus_Widget extends WP_Widget {

	function wordplus_Widget() {
		$widget_ops = array( 'classname' => 'navigation-widget', 'description' => __('Recommend to use on Sticky Widget Area', 'wordplus') );
		
		
		
		$this->WP_Widget( 'navigation-widget', __('Navigation', 'wordplus'), $widget_ops );
	}
	
	function widget( $args, $instance ) {
		extract( $args );

		//Our variables from the widget settings.
		$title = apply_filters('widget_title', $instance['title'] );
		
		echo $before_widget;

		// Display the widget title 
		if ( $title )
			echo $before_title . $title . $after_title;
			echo '<div class="widget-content"><p></p></div>';
		echo $after_widget;
	}

	//Update the widget 
	 
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		//Strip tags from title and name to remove HTML 
		$instance['title'] = strip_tags( $new_instance['title'] );
		return $instance;
	}

	
	function form( $instance ) {

		//Set up some default widget settings.
		$defaults = array( 'title' => __('Navigation', 'wordplus') );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'wordplus'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" style="width:100%;" />
		</p>

	<?php
	}
}

//--- wordplus Search Form -------------------------------------
function wordplus_search_form($custom_search){
										
$default=array('cat_show'=>false,
								'tag_show'=>false,
								'author_show'=>false,
								'archive_show'=>false,
								'field_show'=>true,
								'label_show'=>false,
								'button_show'=>true,
								'rememberd'=>true,
								'advance_show'=>true,
								'close_show'=>false,
								'echo'=>false
									);//default array

foreach((array)$custom_search as $key=>$value){
	$default[$key]=$value;
}
//--base vars------------------------
global $WP_Query,$query,$wp_user;
$cat_option='';$tag_option='';$author_option='';$archive_option='';
$advance_option='';$close_option='';$field_option='';$button_option='';
$cat_selected=get_query_var('cat');
$tag_selected=get_query_var('tag');
$author_selected=get_query_var('author');
$day_selected=get_query_var('day');
$month_selected=get_query_var('monthnum');
$year_selected=get_query_var('year');

if($day_selected==0)$day_selected='';
if($month_selected==0)$month_selected='';
if($year_selected==0)$year_selected='';



//------------------------------------

//--------category--------------------	
	if($default['cat_show']==1):
	$categories = get_categories(); 
		$cat_option='<li><ul>';
		if($default['label_show']):
			$cat_option .='<li class="cat-label">'.__('Category ','wordplus').'</li>';
		endif;	
				$cat_option .='<li class="search-cat"><select name="cat" id="searchcat" ><option value="">'.__('All','wordplus').'</option>';
			foreach ($categories as $category) {
				$cat_option .= '<option value="'.$category->cat_ID.'"';
					if(($cat_selected == $category->cat_ID)&&($default['rememberd']==1)):
						$cat_option .=' selected';
					endif;
				$cat_option .= '>'.$category->cat_name;
				$cat_option .= '</option>';
			}
		$cat_option .= '</select></li></ul></li>';
	endif;
//--------tag--------------------		
	if($default['tag_show']==1):
		$tags = get_categories('taxonomy=post_tag'); 
			$tag_option='<li><ul>';
				if($default['label_show']):
					$tag_option .='<li class="tag-label">'.__('Tag ','wordplus').'</li>';
				endif;
			$tag_option .='<li class="search-tag" ><select name="tag" id="searchtag" ><option value="">'.__('All','wordplus').'</option>';
			
			foreach ($tags as $tag) {
				$tag_option .= '<option value="'.$tag->slug.'"';
					if(($tag_selected == $tag->slug)&&($default['rememberd']==1)):
						$tag_option .=' selected';
					endif;
				$tag_option .= '>'.$tag->cat_name;
				$tag_option .= '</option>';
			}
			$tag_option .= '</select></li></ul></li>';
	endif;
//--------author--------------------		

if($default['author_show']==1):
	$authors=get_users(array('who'=>'authors','fields'=>array('id','display_name')));
	$author_option='<li><ul>';
			if($default['label_show']):
				$author_option .='<li class="author-label">'.__('Author ','wordplus').'</li>';
			endif;
			$author_option .='<li class="search-author" ><select name="author" id="searchauthor" ><option value="">'.__('All','wordplus').'</option>';
			
			foreach ($authors as $author) {
				$author_option .= '<option value="'.$author->id.'"';
					if(($author_selected == $author->id)&&($default['rememberd']==1)):
						$author_option .=' selected';
					endif;
				$author_option .= '>'.$author->display_name;
				$author_option .= '</option>';
			}
			$author_option .= '</select></li></ul></li>';
	endif;
	

//--------archive--------------------		
if($default['archive_show']==1):
	$archive_option='<li><ul>';
			if($default['label_show']):
				$archive_option .='<li class="archive-label">'.__('Date ','wordplus').'</li>';
			endif;
			$archive_option .='<li class="archive-field">
									<input type="text" value="' . $year_selected . '" name="year" id="year" size="3" placeholder="'.__('year','wordplus').'" />
									<input type="text" value="' . $month_selected . '" name="monthnum" id="monthnum" size="2" placeholder="'.__('month','wordplus').'" />
									<input type="text" value="' . $day_selected. '" name="day" id="day" size="1" placeholder="'.__('day','wordplus').'" />
								</li>
		</ul>
	</li>';
	endif;
//--------search field--------------------		
	if($default['field_show']==1):
	$field_option='<li><ul>';
			if($default['label_show']):
				$field_option .='<li class="search-label">'.__('Search for ','wordplus').'</li>';
			endif;
			$field_option .='<li class="search-field"><input type="text" value="' . get_search_query() . '" name="s"  placeholder="'.__('Search','wordplus').'" /></li>
		</ul>
	</li>';
	endif;

//--------search button--------------------		
	if($default['button_show']==1):
		$button_option='<li>
							<input type="submit" class="search-submit" value="'. esc_attr__( 'Search','wordplus' ) .'" />
					   </li>';
	endif;
//--------links--------------------			
	if($default['advance_show']==1):
		$advance_option='<li><a class="advancesearch" href="">'.__('advance search','wordplus').'</a></li>';
	endif;
	
	if($default['close_show']==1):
		$close_option='<li><a class="advancesearch-cancel">'.__('cancel','wordplus').'<i class="icon-cancel"></i></a></li>';
	endif;
//--------final form-------------------		
		$form = '<form role="search" method="get" class="searchform" action="' . home_url( '/' ) . '" ><ul>
			'.$cat_option.$tag_option.$author_option.$archive_option.$field_option.$button_option.$advance_option.$close_option.'
			</ul></form>';
		
		if($default['echo']==1):
			echo $form;
		else:
			return $form;
		endif;
	
}
add_filter( 'get_search_form', 'wordplus_search_form',10,1 );


//wordplus custom header
function wordplus_custom_header_setup() {
		$args = array(
		'default-text-color'     => '',
		'default-image'          => '',
		'random-default'         => false,
		'height'                 => 300,
		'width'                  => 1600,
		'flex-height'            => true,
	    'flex-width'             => true,
		'header-text'            => true,
		'uploads'                => true,
		'wp-head-callback'       => 'wordplus_custom_header',
		'admin-head-callback'    => '',
		'admin-preview-callback' => ''
		);
	
	add_theme_support( 'custom-header', $args );
	
}
add_action( 'after_setup_theme', 'wordplus_custom_header_setup' );

function wordplus_custom_header() {
	$header_image = get_header_image();
	$text_color   = get_header_textcolor();
	$output_style='<style type="text/css" id="wordplus-header-css">';
if ( ! empty( $header_image ) ) {
		$output_style .='
		.banner{
			background: url('.get_header_image().') no-repeat scroll top;
			background-size: 1600px auto;
		}';
}
if ( ! display_header_text() ) {
	$output_style .='
		.site-title,
		.site-description {
			display:none;
		}';
}
if ( $text_color != get_theme_support( 'custom-header', 'default-text-color' ) ) {
		$output_style .='
		#site-title{
			color: #'.esc_attr( $text_color ).';
		}';
}
$output_style .= '</style>';
echo $output_style;
}

/* wordplus custom background */
function wordplus_custom_background_setup(){
	global $wp_version;
	$args = array(
			'default-color'          => '',
			'default-image'          => '',
			'wp-head-callback'       => 'wordplus_custom_background',
			'admin-head-callback'    => '',
			'admin-preview-callback' => ''
			);
	
	add_theme_support( 'custom-background',$args ); 

}
add_action( 'after_setup_theme', 'wordplus_custom_background_setup' );

function wordplus_custom_background(){

			$background = set_url_scheme( get_background_image() );
	        $color = get_theme_mod( 'background_color' );
	
	        if ( ! $background && ! $color )
	                return;
	
	        $style = $color ? "background-color: #$color;" : '';
	
	        if ( $background ) {
	                $image = " background-image: url('$background');";
	
	                $repeat = get_theme_mod( 'background_repeat', 'repeat' );
	                if ( ! in_array( $repeat, array( 'no-repeat', 'repeat-x', 'repeat-y', 'repeat' ) ) )
	                        $repeat = 'repeat';
	                $repeat = " background-repeat: $repeat;";
	                $position = get_theme_mod( 'background_position_x', 'left' );
	                if ( ! in_array( $position, array( 'center', 'right', 'left' ) ) )
	                        $position = 'left';
	                $position = " background-position: top $position;";
	
	                $attachment = get_theme_mod( 'background_attachment', 'scroll' );
	                if ( ! in_array( $attachment, array( 'fixed', 'scroll' ) ) )
	                        $attachment = 'scroll';
	                $attachment = " background-attachment: $attachment;";
	
	                $style .= $image . $repeat . $position . $attachment;
	        }	
	
	echo '<style type="text/css" id="wordplus-background-css">
	div.content{'.trim( $style ).'}
	</style>';
	
}
//end

//-----------------------------------------------------------
$google_fonts = array(
							''		=> __('Default','wordplus'),
							'ABeeZee'		=> 'ABeeZee',
							'Abel'		=> 'Abel',
							'Abril+Fatface'		=> 'Abril Fatface',
							'Acme'		=> 'Acme',
							'Allan'		=> 'Allan',
							'Allerta+Stencil'		=> 'Allerta Stencil',
							'Allura'		=> 'Allura',
							'Amarante'		=> 'Amarante',
							'Anaheim'		=> 'Anaheim',
							'Andika'		=> 'Andika',
							'Arbutus'		=> 'Arbutus',
							'Atomic+Age'		=> 'Atomic Age',
							'Audiowide'		=> 'Audiowide',
							'Autour'		=> 'Autour',
							'Average'		=> 'Average',
							'Averia'		=> 'Averia',
							'Bad+Script'		=> 'Bad Script',
							'Basic'		=> 'Basic',
							'Berkshire Swash'		=> 'Berkshire Swash',
							'Black+Ops+One'		=> 'Black Ops One',
							'Boogaloo'		=> 'Boogaloo',
							'Bowlby+One'		=> 'Bowlby One',
							'Bree+Serif'		=> 'Bree Serif',
							'Cagliostro'		=> 'Cagliostro',
							'Cambo'		=> 'Cambo',
							'Capriola'		=> 'Capriola',
							'Changa'		=> 'Changa',
							'Chango'		=> 'Chango',
							'Chau+Philomene'		=> 'Chau Philomene',
							'Chelsea+Market'		=> 'Chelsea Market',
							'Comfortaa'		=> 'Comfortaa',
							'Convergence'		=> 'Convergence',
							'Courgette'		=> 'Courgette',
							'Cuprum'		=> 'Cuprum',
							'Delius+Swash+Caps'		=> 'Delius Swash Caps',
							'Electrolize'		=> 'Electrolize',
							'Exo'		=> 'Exo',
							'Fascinate'		=> 'Fascinate',
							'Fugaz'		=> 'Fugaz',
							'Gabriela'		=> 'Gabriela',
							'Glegoo'		=> 'Glegoo',
							'Henny+Penny'		=> 'Henny Penny',
							'Inder'		=> 'Inder',
							'Kavoon'		=> 'Kavoon',
							'Kaushan+Script'		=> 'Kaushan Script',
							'Kite'		=> 'Kite',
							'Lemon'		=> 'Lemon',
							'Lily'		=> 'Lily',
							'Limelight'		=> 'Limelight',
							'Marko+One'		=> 'Marko One',
							'Merienda'		=> 'Merienda',
							'Open+Sans'		=> 'Open Sans',
							'Source'		=> 'Source',
							'Share+Tech'    => 'Share Tech',
							'Tauri'		=> 'Tauri',
							'Viga'		=> 'Viga'
						);
	$colors_style = array(
							'red'		=> __('Red','wordplus'),
							'blue'		=> __('Blue','wordplus'),
							'green'		=> __('Green','wordplus'),
							'orange'		=> __('Orange','wordplus'),
							'violet'		=> __('Violet','wordplus'),
							'pink'		=> __('Pink','wordplus'),
							'dark-blue'		=> __('Dark Blue','wordplus'),
							'grey'		=> __('Grey','wordplus')
						);
	$light_dark = array(
							'light-style'		=> __('Light','wordplus'),
							'dark-style'		=> __('Dark','wordplus')
						);
						

//font sanitize
function wordplus_font_sanitize( $input ) {
   global $google_fonts;
        
    if ( array_key_exists( $input, $google_fonts ) ) {
        return $input;
    } else {
        return '';
    }
}
//color sanitize
function wordplus_color_sanitize( $input ) {
   global $colors_style, $light_dark;
        
    if ( array_key_exists( $input, $colors_style ) ||  array_key_exists( $input, $light_dark )) {
        return $input;
    } else {
        return '';
    }
}
//boolian sanitize
function wordplus_bool_sanitize( $input ) {
   $wordplus_customize_bool = array(
									'yes' => 'Yes',
									'no' => 'No',
									'1',
									'2',
									'3',
									'4'
									);
        
    if ( array_key_exists( $input, $wordplus_customize_bool ) ) {
        return $input;
    } else {
        return '';
    }
}

function wordplus_global_sanitize($input){
	return $input;
}

function wordplus_register_theme_customizer( $wp_customize ) {
	
	global $google_fonts, $colors_style, $light_dark;
	
	$font_list = $google_fonts;
	
//-------------------------
	$wp_customize->add_section(
		'wordplus_font_options',
		array(
			'title'     => __('Fonts','wordplus'),
			'priority'  => 200
		)
	);

	// Headers Font
	$wp_customize->add_setting(
		'wordplus_headers_font',
		array(
			'default'    =>  '',
			'sanitize_callback' => 'wordplus_font_sanitize'
			
		)
	);

	$wp_customize->add_control(
		'wordplus_headers_font',
		array(
			'section'   => 'wordplus_font_options',
			'label'     => __('Headers Font','wordplus'),
			'type'       => 'select',
            'choices'    => $font_list
		)
	);
	
	//Body Font
	$wp_customize->add_setting(
		'wordplus_body_font',
		array(
			'default'    =>  '',
			 'sanitize_callback' => 'wordplus_font_sanitize'
			
		)
	);

	$wp_customize->add_control(
		'wordplus_body_font',
		array(
			'section'   => 'wordplus_font_options',
			'label'     => __('Body Font','wordplus'),
			'type'       => 'select',
            'choices'    => $font_list
		)
	);

	//Theme styles
	
						

	$wp_customize->add_section(
		'wordplus_colors_options',
		array(
			'title'     => __('Theme Style','wordplus'),
			'priority'  => 200
		)
	);

	//Light Dark
	$wp_customize->add_setting(
		'wordplus_light_dark',
		array(
			'default'    =>  'light-style',
			'sanitize_callback' => 'wordplus_color_sanitize'
			
		)
	);

	$wp_customize->add_control(
		'wordplus_light_dark',
		array(
			'section'   => 'wordplus_colors_options',
			'label'     => __('Light or Dark?','wordplus'),
			'type'       => 'select',
            'choices'    => $light_dark
		)
	);
	
	//Colors Style
	$wp_customize->add_setting(
		'wordplus_colors_style',
		array(
			'default'    =>  'blue',
			'sanitize_callback' => 'wordplus_color_sanitize'
			
		)
	);

	$wp_customize->add_control(
		'wordplus_colors_style',
		array(
			'section'   => 'wordplus_colors_options',
			'label'     => __('Colors Style','wordplus'),
			'type'       => 'select',
            'choices'    => $colors_style
		)
	);
	
	

	
	//archives layout
	$wp_customize->add_section(
		'wordplus_archive_layout_options',
		array(
			'title'     => __('Archives Layout','wordplus'),
			'priority'  => 200
		)
	);

	$wp_customize->add_setting(
		'wordplus_primary_column',
		array(
			'default'    =>  '1',
			'sanitize_callback' => 'wordplus_global_sanitize'
			
		)
	);
	 $wp_customize->add_control( 'wordplus_primary_column', array(
            'label'      => __( "How many columns the Articles area will divid to? ( Note : it will change depend on client's browser width )","wordplus" ),
            'section'    => 'wordplus_archive_layout_options',
            'type'       => 'radio',
            'choices'    => array(
				'1'     => __('One Column','wordplus'),
			   '2'  => __('Two Column','wordplus'),
			   '3'  => __('Three Column','wordplus'),
			   '4'  => __('Four Column','wordplus')
                
                
            ),
        ) );
		
		$wp_customize->add_setting(
		'wordplus_article_spacer',
		array(
			'default'    =>  'yes',
			'sanitize_callback' => 'wordplus_bool_sanitize'
			
		)
	);
	 $wp_customize->add_control( 'wordplus_article_spacer', array(
            'label'      => __( "Make columns level by space?","wordplus" ),
            'section'    => 'wordplus_archive_layout_options',
            'type'       => 'radio',
            'choices'    => array(
				'yes'     => __('Yes','wordplus'),
			   'no'  => __('No','wordplus'),
			 ),
        ) );
		
	$wp_customize->add_setting(
		'wordplus_post_info_show',
		array(
			'default'    =>  'yes',
			'sanitize_callback' => 'wordplus_bool_sanitize'
			
		)
	);
	
	
	 $wp_customize->add_control( 'wordplus_post_info_show', array(
            'label'      => __( 'show post info on Home and archive pages? ','wordplus' ),
            'section'    => 'wordplus_archive_layout_options',
            'type'       => 'radio',
            'choices'    => array(
				'yes'     => __('Yes','wordplus'),
				'no'  => __('No','wordplus')
                
                
            ),
        ) );
		
	$wp_customize->add_setting(
		'wordplus_auto_excerpt',
		array(
			'default'    =>  'yes',
			'sanitize_callback' => 'wordplus_bool_sanitize'
			
		)
	);
	 $wp_customize->add_control( 'wordplus_auto_excerpt', array(
            'label'      => __( 'Auto excerpt posts for Home and archive pages?','wordplus' ),
            'section'    => 'wordplus_archive_layout_options',
            'type'       => 'radio',
            'choices'    => array(
				'yes'     => __('Yes','wordplus'),
			   'no'  => __('No, I will excerpt posts manualy','wordplus')
                
                
            ),
        ) );
		//post thumbnail
		$wp_customize->add_section(
		'wordplus_f_img_options',
		array(
			'title'     => __('Featured Image','wordplus'),
			'priority'  => 200
		)
	);
		
		$wp_customize->add_setting(
		'wordplus_featured_image_show',
		array(
			'default'    =>  'yes',
			'sanitize_callback' => 'wordplus_bool_sanitize'
			
		)
	);
	 $wp_customize->add_control( 'wordplus_featured_image_show', array(
            'label'      => __( 'show featured image on archive pages? ','wordplus' ),
            'section'    => 'wordplus_f_img_options',
            'type'       => 'radio',
            'choices'    => array(
				'yes'     => __('Yes','wordplus'),
			   'no'  => __('No','wordplus')
                
                
            ),
        ) );
		
		$wp_customize->add_setting(
		'wordplus_f_img_show_single',
		array(
			'default'    =>  'no',
			'sanitize_callback' => 'wordplus_bool_sanitize'
			
		)
	);
	 $wp_customize->add_control( 'wordplus_f_img_show_single', array(
            'label'      => __( 'show featured image on single pages? ','wordplus' ),
            'section'    => 'wordplus_f_img_options',
            'type'       => 'radio',
            'choices'    => array(
                'yes'     => __('Yes','wordplus'),
				'no'  => __('No','wordplus')
                
                
            ),
        ) );
		
		//links
		$wp_customize->add_section(
		'wordplus_links_options',
		array(
			'title'     => __('Links','wordplus'),
			'priority'  => 200
		)
	);
		
		$wp_customize->add_setting(
		'wordplus_external_links_show',
		array(
			'default'    =>  'yes',
			'sanitize_callback' => 'wordplus_bool_sanitize'
			
		)
	);
	 $wp_customize->add_control( 'wordplus_external_links_show', array(
            'label'      => __( 'show External Links in iframe? ','wordplus' ),
            'section'    => 'wordplus_links_options',
            'type'       => 'radio',
            'choices'    => array(
				'yes'     => __('Yes','wordplus'),
			   'no'  => __('No','wordplus')
                
                
            ),
        ) );
		
		//Lazy Content
		$wp_customize->add_section(
		'wordplus_lazy_options',
		array(
			'title'     => __('Lazy Content','wordplus'),
			'priority'  => 200
		)
	);
		
		$wp_customize->add_setting(
		'wordplus_lazy_content',
		array(
			'default'    =>  'yes',
			'sanitize_callback' => 'wordplus_global_sanitize'
						
		)
	);
	 $wp_customize->add_control( 'wordplus_lazy_content', array(
            'label'      => __( 'Enable Lazy Content Effects ','wordplus' ),
            'section'    => 'wordplus_lazy_options',
            'type'       => 'radio',
            'choices'    => array(
				'yes'     => __('Yes','wordplus'),
			   'no'  => __('No','wordplus')
                
                
            ),
        ) );
		
	
				
	  
} 
add_action( 'customize_register', 'wordplus_register_theme_customizer' );

function wordplus_customizer_css() {
	$light_dark='';
	$color_style='';
	$final_fonts='';
	$fonts=array();
	$light_dark = trim(esc_attr(get_theme_mod('wordplus_light_dark')));
	$color_style = trim(esc_attr(get_theme_mod('wordplus_colors_style')));
	$headers_font = esc_attr(get_theme_mod( 'wordplus_headers_font' ));
	$headers_font = trim(ucwords(str_replace ( '+',' ', $headers_font )));
	$body_font = esc_attr(get_theme_mod( 'wordplus_body_font' ));
	$body_font = trim(ucwords(str_replace ( '+',' ', $body_font )));

	
	
	
		if(!$light_dark):
			$light_dark ='light-style';
		endif;
			wp_enqueue_style('light-dark',get_template_directory_uri().'/css/'.$light_dark.'.css');
		if(!$color_style):
			$color_style ='blue';
		endif;
			wp_enqueue_style('color-style',get_template_directory_uri().'/css/color-'.$color_style.'.css');
		if( $headers_font) :
			$fonts[]=$headers_font;
		endif;
		
		if( $body_font):
			$fonts[]=$body_font;
		endif;
		
		if($fonts):
			$final_fonts=implode('|',$fonts);
		endif;
			
		if($final_fonts): ?>
				<link href='http://fonts.googleapis.com/css?family=<?php echo $final_fonts;?>' rel='stylesheet' type='text/css'>
		<?php endif; ?>
			
			<style id="fonts-style" rel='stylesheet' type="text/css">
				<?php if($body_font): ?>
					body {font-family : <?php echo $body_font; ?>,'<?php echo $body_font; ?>' }
				<?php endif; ?>
				
				<?php if($headers_font): ?>
					h1,h2,h3,h4,h5,h6 { font-family: <?php echo $headers_font; ?>,'<?php echo $headers_font; ?>'; }
				<?php else:
						if(!is_rtl()): ?>
							h1,h2,h3,h4,h5,h6 { font-family: "Open Sans", Helvetica, Arial, sans-serif; }
						<?php else: ?>
							h1,h2,h3,h4,h5,h6 { font-family: Tahoma; }
						<?php endif; ?>
				<?php endif; ?>
				
			</style>
	     
		 	 
<?php }
add_action( 'wp_head', 'wordplus_customizer_css' );



?>